@@ -16,19 +16,19 @@ from matplotlib.artist import Artist
 
 _logger = logging.getLogger(__name__)
 
-RATIO_OPTIONS = {"golden_ratio", "equal", "from_rows"}
+RATIO_OPTIONS = {'golden_ratio', 'equal', 'from_rows'}
 
 
 def add_values_to_bars(
     axis,
-    bar_type="bar",
-    position="c",
-    label_format="{:.0f}",
+    bar_type='bar',
+    position='c',
+    label_format='{:.0f}',
     x_offset=0,
     y_offset=0,
-    color="k",
-    horizontalalignment="center",
-    verticalalignment="center",
+    color='k',
+    horizontalalignment='center',
+    verticalalignment='center',
 ):
     """
     Add the values of the bars as number in the center
@@ -73,19 +73,19 @@ def add_values_to_bars(
         ww = b.x1 - b.x0
 
         # determine the position of the text
-        if position == "c":
+        if position == 'c':
             # center
             (px, py) = (cx, cy)
-        elif position == "t":
+        elif position == 't':
             # top
             (px, py) = (cx, cy + hh / 2)
-        elif position == "b":
+        elif position == 'b':
             # bottom
             (px, py) = (cx, cy - hh / 2)
-        elif position == "l":
+        elif position == 'l':
             # left
             (px, py) = (cx - ww / 2, cy)
-        elif position == "r":
+        elif position == 'r':
             # right
             (px, py) = (cx + ww / 2, cy)
         else:
@@ -95,9 +95,9 @@ def add_values_to_bars(
         (px, py) = (px + x_offset, py + y_offset)
 
         # determine the value of the bar
-        if bar_type == "bar":
+        if bar_type == 'bar':
             value = hh
-        elif bar_type == "barh":
+        elif bar_type == 'barh':
             value = ww
         else:
             raise ValueError(f"type = {bar_type} not recognised. Please check")
@@ -125,8 +125,8 @@ def add_cbs_logo_to_plot(
     width=None,
     height=None,
     zorder_start=1,
-    fillcolor="cbs:highchartslichtgrijs",
-    edgecolor="cbs:logogrijs",
+    fillcolor='cbs:highchartslichtgrijs',
+    edgecolor='cbs:logogrijs',
 ):
     """
     Add the CBS logo to the plot.
@@ -192,7 +192,6 @@ def add_cbs_logo_to_plot(
 
     zorder = zorder_start
     for points_in_out in all_points:
-
         for ii, points in enumerate(points_in_out):
             points[:, :2] *= fig.dpi / 25.4
             points[:, 0] += x0
@@ -392,15 +391,15 @@ def add_axis_label_background(
     margin=0.05,
     x0=None,
     y0=None,
-    loc="east",
+    loc='east',
     radius_corner_in_mm=1,
     logo_margin_x_in_mm=1,
     logo_margin_y_in_mm=1,
     add_logo=True,
     aspect=None,
-    backgroundcolor="cbs:highchartslichtgrijs",
-    logo_fillcolor="cbs:highchartslichtgrijs",
-    logo_edgecolor="cbs:logogrijs",
+    backgroundcolor='cbs:highchartslichtgrijs',
+    logo_fillcolor='cbs:highchartslichtgrijs',
+    logo_edgecolor='cbs:logogrijs',
 ):
     """
     Add a background to the axis labels.
@@ -458,7 +457,7 @@ def add_axis_label_background(
         axes.transAxes.inverted()
     )
 
-    if loc == "east":
+    if loc == 'east':
         if x0 is None:
             x0 = bbox_axi.x0 - margin * bbox_axi.width
         x1 = 0
@@ -466,7 +465,7 @@ def add_axis_label_background(
         y0 = 0
         y1 = 1
 
-    elif loc == "south":
+    elif loc == 'south':
         x0 = 0
         x1 = 1
 
@@ -485,11 +484,11 @@ def add_axis_label_background(
     _logger.debug(f"Adding rectangle with width {width} and height {height}")
 
     # eerste vierkant zorgt voor rechte hoeken aan de rechterkant
-    if loc == "east":
+    if loc == 'east':
         rec_p = (x0 + width / 2, y0)
         rec_w = width / 2
         rec_h = height
-    elif loc == "south":
+    elif loc == 'south':
         rec_p = (x0, y0 + height / 2)
         rec_w = width
         rec_h = height / 2
@@ -528,7 +527,7 @@ def add_axis_label_background(
         transform=fig.transFigure,
         zorder=0,
     )
-    p2.set_boxstyle("round", pad=pad)
+    p2.set_boxstyle('round', pad=pad)
     p2.set_transform(axes.transAxes)
     p2.set_clip_on(False)
 
@@ -602,7 +601,7 @@ def format_thousands_label(value: float, _: object) -> str:
         Formatted value with spaces as a thousand separator.
     """
     int_value = int(value)
-    return "{:,}".format(int_value).replace(",", " ")
+    return '{:,}'.format(int_value).replace(',', ' ')
 
 
 def swap_legend_boxes(
@@ -635,7 +634,7 @@ def swap_legend_boxes(
     reordered_labels: List[str] = labels.copy()
 
     if len(reordered_labels) != len(reordered_handles):
-        raise ValueError("Number of handles and labels must be equal.")
+        raise ValueError('Number of handles and labels must be equal.')
 
     rows_per_col: Dict[int, int] = {}
 
